@@ -11,7 +11,7 @@ if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
 
 
 class JobOffer(Model):
-    author = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='jobOffers', on_delete=models.CASCADE)
+    author = models.ForeignKey(settings.AUTH_USER_MODEL, related_name='jobOffers', on_delete=models.SET_NULL, null=True, blank=True)
     title = models.CharField(max_length=255, blank=True, null=True)
     description = models.TextField(blank=True, null=True)
     skills = models.ManyToManyField(Skill, blank=True)
@@ -31,4 +31,7 @@ class JobOffer(Model):
         rdf_type = 'hd:joboffer'
 
     def __str__(self):
-        return '{} ({})'.format(self.title, self.author.get_full_name())
+        try:
+            return '{} -> {} ({})'.format(self.author.urlid, self.title, self.urlid)
+        except:
+            return self.urlid
